
## V3.0.3 - 2016-06-20

* CHG: use jQuery 3.0 instead of EventEmitter2 and lodash
* CHG: use phantomjs for browser testing
* CHG: improve bundle technique, which makes it an UMD module since now.

## V3.0.2 - 2016-03-08

* FIX: remove useless return after throwing error
* ADD: coffeelint build task
* ADD: test coverage build task and increase test coverage

## V3.0.1 - 2016-03-08

* FIX: incorrect publish of v3.0.0 on npm

## V3.0.0 - 2016-03-08

* Fresh new start. Now Providing event emitter, mixins and plugins features for browser or node sub-modules.
* Changed: replace jQuery with lodash as dependency.
* Changed: replace grunt with gulp for build and publish automation.
* Changed: use jade to generate doc site instead of jekyll.
* Removed: i18n features, please use dedicated i18n module like [i18next](https://github.com/i18next/i18next) instead.

## Older Versions

Change logs under V3.0.0 are not recorded here, please check [Release History](https://github.com/mycolorway/simple-module/releases).
